@@ -1,8 +1,11 @@
+pub mod context_paper;
 pub mod flex_paper;
 pub mod grid_paper;
 pub mod horizontal_paper;
 pub mod modal_paper;
 pub mod paper;
 pub mod scroll_paper;
+pub mod text_tooltip_paper;
+pub mod tooltip_paper;
 pub mod vertical_paper;
 pub mod wrap_paper;
